@@ -155,6 +155,7 @@ pcaids.nests <- function(shares,margins,knownElast,mktElast=-1,
                          prices,ownerPre,ownerPost,
                          nests=rep(1,length(shares)),
                          knownElastIndex=1,
+                         insideSize = NA_real_,
                          mcDelta=rep(0, length(shares)),
                          subset=rep(TRUE, length(shares)),
                          priceStart=runif(length(shares)),
@@ -182,7 +183,7 @@ pcaids.nests <- function(shares,margins,knownElast,mktElast=-1,
     result <- new("PCAIDSNests",shares=shares,
                   prices=prices,
                   quantities=shares,
-                  margins=margins,mcDelta=mcDelta,subset=subset,
+                  margins=margins,mcDelta=mcDelta,subset=subset,insideSize = insideSize,
                   knownElast=knownElast,mktElast=mktElast,nests=nests,
                   nestsParms=nestsParmStart, diversion=diversions,
                   ownerPre=ownerPre,ownerPost=ownerPost,knownElastIndex=knownElastIndex,
